@@ -19,8 +19,8 @@ package rewrite
 import (
 	networking "k8s.io/api/networking/v1"
 
-	"github.com/open-cluster-management/management-ingress/pkg/ingress/annotations/parser"
-	"github.com/open-cluster-management/management-ingress/pkg/ingress/resolver"
+	"github.com/stolostron/management-ingress/pkg/ingress/annotations/parser"
+	"github.com/stolostron/management-ingress/pkg/ingress/resolver"
 )
 
 // Config describes the per location redirect config
