@@ -1,6 +1,6 @@
 /*
 ** FFI C callback handling.
-** Copyright (C) 2005-2020 Mike Pall. See Copyright Notice in luajit.h
+** Copyright (C) 2005-2017 Mike Pall. See Copyright Notice in luajit.h
 */
 
 #include "lj_obj.h"
@@ -61,24 +61,8 @@ static MSize CALLBACK_OFS2SLOT(MSize ofs)
 
 #elif LJ_TARGET_PPC
 
-#if LJ_ARCH_PPC_OPD
-
-#define CALLBACK_SLOT2OFS(slot)		(24*(slot))
-#define CALLBACK_OFS2SLOT(ofs)		((ofs)/24)
-#define CALLBACK_MAX_SLOT		(CALLBACK_OFS2SLOT(CALLBACK_MCODE_SIZE))
-
-#elif LJ_ARCH_PPC_ELFV2
-
-#define CALLBACK_SLOT2OFS(slot)		(4*(slot))
-#define CALLBACK_OFS2SLOT(ofs)		((ofs)/4)
-#define CALLBACK_MAX_SLOT		(CALLBACK_MCODE_SIZE/4 - 10)
-
-#else
-
 #define CALLBACK_MCODE_HEAD		24
 
-#endif
-
 #elif LJ_TARGET_MIPS32
 
 #define CALLBACK_MCODE_HEAD		20
@@ -123,9 +107,9 @@ MSize lj_ccallback_ptr2slot(CTState *cts, void *p)
 /* Initialize machine code for callback function pointers. */
 #if LJ_OS_NOJIT
 /* Disabled callback support. */
-#define callback_mcode_init(g, p)	(p)
+#define callback_mcode_init(g, p)	UNUSED(p)
 #elif LJ_TARGET_X86ORX64
-static void *callback_mcode_init(global_State *g, uint8_t *page)
+static void callback_mcode_init(global_State *g, uint8_t *page)
 {
   uint8_t *p = page;
   uint8_t *target = (uint8_t *)(void *)lj_vm_ffi_callback;
@@ -159,10 +143,10 @@ static void *callback_mcode_init(global_State *g, uint8_t *page)
       *p++ = XI_JMPs; *p++ = (uint8_t)((2+2)*(31-(slot&31)) - 2);
     }
   }
-  return p;
+  lua_assert(p - page <= CALLBACK_MCODE_SIZE);
 }
 #elif LJ_TARGET_ARM
-static void *callback_mcode_init(global_State *g, uint32_t *page)
+static void callback_mcode_init(global_State *g, uint32_t *page)
 {
   uint32_t *p = page;
   void *target = (void *)lj_vm_ffi_callback;
@@ -181,10 +165,10 @@ static void *callback_mcode_init(global_State *g, uint32_t *page)
     *p = ARMI_B | ((page-p-2) & 0x00ffffffu);
     p++;
   }
-  return p;
+  lua_assert(p - page <= CALLBACK_MCODE_SIZE);
 }
 #elif LJ_TARGET_ARM64
-static void *callback_mcode_init(global_State *g, uint32_t *page)
+static void callback_mcode_init(global_State *g, uint32_t *page)
 {
   uint32_t *p = page;
   void *target = (void *)lj_vm_ffi_callback;
@@ -201,64 +185,29 @@ static void *callback_mcode_init(global_State *g, uint32_t *page)
     *p = A64I_LE(A64I_B | A64F_S26((page-p) & 0x03ffffffu));
     p++;
   }
-  return p;
+  lua_assert(p - page <= CALLBACK_MCODE_SIZE);
 }
 #elif LJ_TARGET_PPC
-#if LJ_ARCH_PPC_OPD
-register void *vm_toc __asm__("r2");
-static void *callback_mcode_init(global_State *g, uint64_t *page)
-{
-  uint64_t *p = page;
-  void *target = (void *)lj_vm_ffi_callback;
-  MSize slot;
-  for (slot = 0; slot < CALLBACK_MAX_SLOT; slot++) {
-    *p++ = (uint64_t)target;
-    *p++ = (uint64_t)vm_toc;
-    *p++ = (uint64_t)g | ((uint64_t)slot << 47);
-  }
-  return p;
-}
-#else
-static void *callback_mcode_init(global_State *g, uint32_t *page)
+static void callback_mcode_init(global_State *g, uint32_t *page)
 {
   uint32_t *p = page;
   void *target = (void *)lj_vm_ffi_callback;
   MSize slot;
-#if LJ_ARCH_PPC_ELFV2
-  // Needs to be in sync with lj_vm_ffi_callback.
-  lua_assert(CALLBACK_MCODE_SIZE == 4096);
-  for (slot = 0; slot < CALLBACK_MAX_SLOT; slot++) {
-    *p = PPCI_B | (((page+CALLBACK_MAX_SLOT-p) & 0x00ffffffu) << 2);
-    p++;
-  }
-  *p++ = PPCI_LI | PPCF_T(RID_SYS1) | ((((intptr_t)target) >> 32) & 0xffff);
-  *p++ = PPCI_LI | PPCF_T(RID_R11) | ((((intptr_t)g) >> 32) & 0xffff);
-  *p++ = PPCI_RLDICR | PPCF_T(RID_SYS1) | PPCF_A(RID_SYS1) | PPCF_SH(32) | PPCF_M6(63-32);  /* sldi */
-  *p++ = PPCI_RLDICR | PPCF_T(RID_R11) | PPCF_A(RID_R11) | PPCF_SH(32) | PPCF_M6(63-32);  /* sldi */
-  *p++ = PPCI_ORIS | PPCF_A(RID_SYS1) | PPCF_T(RID_SYS1) | ((((intptr_t)target) >> 16) & 0xffff);
-  *p++ = PPCI_ORIS | PPCF_A(RID_R11) | PPCF_T(RID_R11) | ((((intptr_t)g) >> 16) & 0xffff);
-  *p++ = PPCI_ORI | PPCF_A(RID_SYS1) | PPCF_T(RID_SYS1) | (((intptr_t)target) & 0xffff);
-  *p++ = PPCI_ORI | PPCF_A(RID_R11) | PPCF_T(RID_R11) | (((intptr_t)g) & 0xffff);
-  *p++ = PPCI_MTCTR | PPCF_T(RID_SYS1);
-  *p++ = PPCI_BCTR;
-#else
   *p++ = PPCI_LIS | PPCF_T(RID_TMP) | (u32ptr(target) >> 16);
-  *p++ = PPCI_LIS | PPCF_T(RID_R11) | (u32ptr(g) >> 16);
+  *p++ = PPCI_LIS | PPCF_T(RID_R12) | (u32ptr(g) >> 16);
   *p++ = PPCI_ORI | PPCF_A(RID_TMP)|PPCF_T(RID_TMP) | (u32ptr(target) & 0xffff);
-  *p++ = PPCI_ORI | PPCF_A(RID_R11)|PPCF_T(RID_R11) | (u32ptr(g) & 0xffff);
+  *p++ = PPCI_ORI | PPCF_A(RID_R12)|PPCF_T(RID_R12) | (u32ptr(g) & 0xffff);
   *p++ = PPCI_MTCTR | PPCF_T(RID_TMP);
   *p++ = PPCI_BCTR;
   for (slot = 0; slot < CALLBACK_MAX_SLOT; slot++) {
-    *p++ = PPCI_LI | PPCF_T(RID_R12) | slot;
+    *p++ = PPCI_LI | PPCF_T(RID_R11) | slot;
     *p = PPCI_B | (((page-p) & 0x00ffffffu) << 2);
     p++;
   }
-#endif
-  return p;
+  lua_assert(p - page <= CALLBACK_MCODE_SIZE);
 }
-#endif
 #elif LJ_TARGET_MIPS
-static void *callback_mcode_init(global_State *g, uint32_t *page)
+static void callback_mcode_init(global_State *g, uint32_t *page)
 {
   uint32_t *p = page;
   uintptr_t target = (uintptr_t)(void *)lj_vm_ffi_callback;
@@ -287,11 +236,11 @@ static void *callback_mcode_init(global_State *g, uint32_t *page)
     p++;
     *p++ = MIPSI_LI | MIPSF_T(RID_R1) | slot;
   }
-  return p;
+  lua_assert(p - page <= CALLBACK_MCODE_SIZE);
 }
 #else
 /* Missing support for this architecture. */
-#define callback_mcode_init(g, p)	(p)
+#define callback_mcode_init(g, p)	UNUSED(p)
 #endif
 
 /* -- Machine code management --------------------------------------------- */
@@ -314,7 +263,7 @@ static void *callback_mcode_init(global_State *g, uint32_t *page)
 static void callback_mcode_new(CTState *cts)
 {
   size_t sz = (size_t)CALLBACK_MCODE_SIZE;
-  void *p, *pe;
+  void *p;
   if (CALLBACK_MAX_SLOT == 0)
     lj_err_caller(cts->L, LJ_ERR_FFI_CBACKOV);
 #if LJ_TARGET_WINDOWS
@@ -331,10 +280,7 @@ static void callback_mcode_new(CTState *cts)
   p = lj_mem_new(cts->L, sz);
 #endif
   cts->cb.mcode = p;
-  pe = callback_mcode_init(cts->g, p);
-  UNUSED(pe);
-  lj_assertCTS((size_t)((char *)pe - (char *)p) <= sz,
-	       "miscalculated CALLBACK_MAX_SLOT");
+  callback_mcode_init(cts->g, p);
   lj_mcode_sync(p, (char *)p + sz);
 #if LJ_TARGET_WINDOWS
   {
@@ -475,9 +421,8 @@ void lj_ccallback_mcode_free(CTState *cts)
 
 #define CALLBACK_HANDLE_GPR \
   if (n > 1) { \
-    lj_assertCTS(((LJ_ABI_SOFTFP && ctype_isnum(cta->info)) ||  /* double. */ \
-		 ctype_isinteger(cta->info)) && n == 2,  /* int64_t. */ \
-		 "bad GPR type"); \
+    lua_assert(((LJ_ABI_SOFTFP && ctype_isnum(cta->info)) ||  /* double. */ \
+		ctype_isinteger(cta->info)) && n == 2);  /* int64_t. */ \
     ngpr = (ngpr + 1u) & ~1u;  /* Align int64_t to regpair. */ \
   } \
   if (ngpr + n <= maxgpr) { \
@@ -609,13 +554,13 @@ static void callback_conv_args(CTState *cts, lua_State *L)
   if (LJ_FR2) {
     (o++)->u64 = LJ_CONT_FFI_CALLBACK;
     (o++)->u64 = rid;
+    o++;
   } else {
     o->u32.lo = LJ_CONT_FFI_CALLBACK;
     o->u32.hi = rid;
     o++;
   }
   setframe_gc(o, obj2gco(fn), fntp);
-  if (LJ_FR2) o++;
   setframe_ftsz(o, ((char *)(o+1) - (char *)L->base) + FRAME_CONT);
   L->top = L->base = ++o;
   if (!ct)
@@ -643,7 +588,7 @@ static void callback_conv_args(CTState *cts, lua_State *L)
       CTSize sz;
       int isfp;
       MSize n;
-      lj_assertCTS(ctype_isfield(ctf->info), "field expected");
+      lua_assert(ctype_isfield(ctf->info));
       cta = ctype_rawchild(cts, ctf);
       isfp = ctype_isfp(cta->info);
       sz = (cta->size + CTSIZE_PTR-1) & ~(CTSIZE_PTR-1);
@@ -717,15 +662,6 @@ static void callback_conv_result(CTState *cts, lua_State *L, TValue *o)
 	*(int32_t *)dp = ctr->size == 1 ? (int32_t)*(int8_t *)dp :
 					  (int32_t)*(int16_t *)dp;
     }
-#if LJ_TARGET_PPC && LJ_ARCH_BITS == 64
-    if (ctr->size <= 4 &&
-       (ctype_isinteger_or_bool(ctr->info) || ctype_isenum(ctr->info))) {
-      if (ctr->info & CTF_UNSIGNED)
-        *(uint64_t *)dp = (uint64_t)*(uint32_t *)dp;
-      else
-        *(int64_t *)dp = (int64_t)*(int32_t *)dp;
-    }
-#endif
 #if LJ_TARGET_MIPS64 || (LJ_TARGET_ARM64 && LJ_BE)
     /* Always sign-extend results to 64 bits. Even a soft-fp 'float'. */
     if (ctr->size <= 4 &&
@@ -744,7 +680,7 @@ lua_State * LJ_FASTCALL lj_ccallback_enter(CTState *cts, void *cf)
 {
   lua_State *L = cts->L;
   global_State *g = cts->g;
-  lj_assertG(L != NULL, "uninitialized cts->L in callback");
+  lua_assert(L != NULL);
   if (tvref(g->jit_base)) {
     setstrV(L, L->top++, lj_err_str(L, LJ_ERR_FFI_BADCBACK));
     if (g->panic) g->panic(L);
@@ -829,7 +765,7 @@ static CType *callback_checkfunc(CTState *cts, CType *ct)
       CType *ctf = ctype_get(cts, fid);
       if (!ctype_isattrib(ctf->info)) {
 	CType *cta;
-	lj_assertCTS(ctype_isfield(ctf->info), "field expected");
+	lua_assert(ctype_isfield(ctf->info));
 	cta = ctype_rawchild(cts, ctf);
 	if (!(ctype_isenum(cta->info) || ctype_isptr(cta->info) ||
 	      (ctype_isnum(cta->info) && cta->size <= 8)) ||
